@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.010_001;
-use version; our $VERSION = version->declare('v0.1.7');
+use version; our $VERSION = version->declare('v0.1.8');
 
 1;
 __END__
@@ -61,10 +61,10 @@ paths to include upon runtime.
 =head1 HOW IT WORKS
 
 Carmel will keep the build directory (artifacts) after a cpanm
-installation in a repository, which defaults to C<$HOME/.perl-carmel/{version}-{archname}/builds>,
+installation in a repository, which defaults to C<$HOME/.carmel/{version}-{archname}/builds>,
 and your directory structure would look like:
 
-  $HOME/.perl-carmel/5.20.1-darwin-2level/builds
+  $HOME/.carmel/5.20.1-darwin-2level/builds
     Plack-1.0033/
       blib/
         arch/
