@@ -23,7 +23,7 @@ sub _find_border {
 }
 
 # This assumes it's run under carmel exec
-my $base = $ENV{PERL_CARMEL_REPO} || "$ENV{HOME}/.perl-carmel/$]-$Config{archname}/builds";
+my $base = $ENV{PERL_CARMEL_REPO} || "$ENV{HOME}/.carmel/$Config{version}-$Config{archname}/builds";
 my $index = _find_border qr!$base/.*?/blib/(lib|arch)?$!, @INC;
 
 if ($index) {
